<?php
namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Teknisa\MAN\Services;
use Teknisa\MAN\Utilities;


class Fidelidade extends \Zeedhi\Framework\Controller\Simple {

    protected $fidelityService;
    protected $clienteService;
    protected $consumidorService;
    protected $salesMessage;
    protected $util;
    protected $entityManager;
    protected $produtoService;
    protected $SMTPService;
    

    public function __construct(Services\Fidelidade $fidelityService, Services\Cliente $clienteService, Services\Consumidor $consumidorService, Utilities\SalesMessage $salesMessage, Utilities\Util $util, \Doctrine\ORM\EntityManager $entityManager, Services\Produto $produtoService, Services\SMTP $SMTPService) {
        $this->fidelityService   = $fidelityService;
        $this->clienteService    = $clienteService;
        $this->consumidorService = $consumidorService;
        $this->salesMessage      = $salesMessage;
        $this->util              = $util;
        $this->entityManager     = $entityManager;
        $this->produtoService    = $produtoService;
        $this->SMTPService       = $SMTPService;
    }

	public function carregaCampanhas(Request\Filter $request, Response $response) {
        $params = $request->getFilterCriteria()->getConditions();

        $IDCAMPANHA = $params[0]['value'];

        if($IDCAMPANHA == 'P'){
            $dadosCampanhas = $this->fidelityService->carregaCampanhasProduto($IDCAMPANHA);
        }else if($IDCAMPANHA == 'V'){
            $dadosCampanhas = $this->fidelityService->carregaCampanhasDotz($IDCAMPANHA);
        }else if($IDCAMPANHA == 'D'){
            $dadosCampanhas = $this->fidelityService->carregaCampanhasDesconto($IDCAMPANHA);
        }

        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('CampanhasRepo', $dadosCampanhas));
    }

    public function carregaTpCampanha(Request\Filter $request, Response $response){
        $tiposCampanha = $this->fidelityService->tiposCampanha();
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('TiposCampanhaRepo', $tiposCampanha));
    }

    public function registrarCampanha(Request\Filter $request, Response $response){
        $params = $request->getFilterCriteria()->getConditions();

        $params =  $this->util->replaceParams($params);

        $DSCAMPANHA      = $params[0]['value'];
        $CDTPCAMPANHA    = $params[1]['value'];
        $DTINIVIGCAMP    = $params[2]['value'];
        $DTFIMVIGCAMP    = $params[3]['value'];
        $IDCAMPANHA      = $params[4]['value'];
        $NRDIASVALPONTO  = $params[5]['value'];
        $IDUTILVOUCHER   = $params[6]['value'];
        $VRPONTOVOUCHER  = $params[7]['value'];
        $NRDIAVALVOUCHER = $params[8]['value'];
        $CDOPERULTATU    = $params[9]['value'];
        $CDOPERINCLUSAO  = $params[10]['value'];
        $NRORG           = $params[11]['value'];
        $IDPONTUACAOCAMP = $params[12]['value'];
        $CDPROMOCAODOTZ  = $params[13]['value'];
        $VRPESOCAMP      = $params[14]['value'];
        $VRPONTOCAMP     = $params[15]['value'];
        $VRVENDAINIDOTZ  = $params[16]['value'];
        $VRVENDAFINDOTZ  = $params[17]['value'];

        $CDCAMPANHA = $this->util->newCode('CAMPANHA', '10');

        $this->fidelityService->registrarCampanha($CDCAMPANHA, $DSCAMPANHA, $CDTPCAMPANHA, $DTINIVIGCAMP, $DTFIMVIGCAMP, $IDCAMPANHA, $NRDIASVALPONTO, $IDUTILVOUCHER, $VRPONTOVOUCHER, $NRDIAVALVOUCHER, $CDOPERULTATU, $CDOPERINCLUSAO, $NRORG, $IDPONTUACAOCAMP, $CDPROMOCAODOTZ, $VRPESOCAMP, $VRPONTOCAMP, $VRVENDAINIDOTZ, $VRVENDAFINDOTZ);
        $dadosFiliais = null;

        if($IDCAMPANHA == 'P'){
            $dadosFiliais = $this->fidelityService->carregaCampanhasEspecificaProduto($CDCAMPANHA, $IDCAMPANHA);
        }else if($IDCAMPANHA == 'V'){
            $dadosFiliais =  $this->fidelityService->carregaCampanhasEspecificaDotz($CDCAMPANHA, $IDCAMPANHA);
        }else if($IDCAMPANHA == 'D'){
            $dadosFiliais =  $this->fidelityService->carregaCampanhasEspecificaDesconto($CDCAMPANHA, $IDCAMPANHA);
        }else if($IDCAMPANHA == 'C'){
            $dadosFiliais =  $this->fidelityService->carregaCampanhasEspecificaBeneficio($CDCAMPANHA, $IDCAMPANHA);
        }

        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('RegistrarCampanhaRepo', $dadosFiliais));
    }

    public function deletarCampanha(Request\Filter $request, Response $response){
        $params = $request->getFilterCriteria()->getConditions();
        $CDCAMPANHA = $params[0]['value'];

        $verificaBENEFICIOCAMP =  $this->fidelityService->verificarBENEFICIOCAMP($CDCAMPANHA);
        $verificaMovimentacao = $this->fidelityService->verificaMovimentacao($CDCAMPANHA);

        if(!empty($verificaBENEFICIOCAMP)){
           $response->addMessage(new Message($this->salesMessage->getMessage(23)));
        }else if(!empty($verificaMovimentacao)){
            $response->addMessage(new Message($this->salesMessage->getMessage(43)));
        }else{

            $this->fidelityService->deletarTodosBrindes($CDCAMPANHA);
            $this->fidelityService->deletarTodosProdutos($CDCAMPANHA);
            $this->fidelityService->deletarTodasFiliais($CDCAMPANHA);
            $this->fidelityService->deletarCampanha($CDCAMPANHA);

            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('nothing', array(array('nothing' => 'nothing'))));
        }
    }

    public function inserirFilial(Request\Filter $request, Response $response){
        $params = $request->getFilterCriteria()->getConditions();

        $CDCAMPANHA      = $params[0]['value'];
        $CDFILIAL        = $params[1]['value'];
        $NRORG           = $params[2]['value'];
        $NRORGINCLUSAO   = $params[3]['value'];
        $CDOPERINCLUSAO  = $params[4]['value'];
        $NRORGULTATU     = $params[5]['value'];
        $CDOPERULTATU    = $params[6]['value'];


        $checkFilial = $this->fidelityService->buscaFilialCampanha($CDFILIAL);

        $this->fidelityService->inserirFilial($CDCAMPANHA, $CDFILIAL, $NRORG, $NRORGINCLUSAO, $CDOPERINCLUSAO, $NRORGULTATU, $CDOPERULTATU);
        $filiaisCampanha = $this->fidelityService->buscaFiliaisCampanha($CDCAMPANHA);
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('FilialCampanhaRepo', $filiaisCampanha));

    }

    public function incluirProduto(Request\Filter $request, Response $response){
        $params = $request->getFilterCriteria()->getConditions();

        $CDCAMPANHA      = $params[0]['value'];
        $CDPRODUTO       = $params[1]['value'];
        $IDPRODUTOGERA   = $params[2]['value'];
        $VRPONTOPROD     = $params[3]['value'];
        $DTINIVIGPROD    = $params[4]['value'];
        $DTFIMVIGPROD    = $params[5]['value'];
        $NRORG           = $params[6]['value'];
        $NRORGINCLUSAO   = $params[7]['value'];
        $CDOPERINCLUSAO  = $params[8]['value'];
        $NRORGULTATU     = $params[9]['value'];
        $CDOPERULTATU    = $params[10]['value'];

        $NRSEQPRODCAMP = $this->util->newCode('PRODCAMPANHA'.$CDCAMPANHA, '10');

        $this->fidelityService->incluirProduto($CDCAMPANHA, $NRSEQPRODCAMP, $CDPRODUTO, $IDPRODUTOGERA, $VRPONTOPROD, $DTINIVIGPROD, $DTFIMVIGPROD, $NRORG, $NRORGINCLUSAO, $CDOPERINCLUSAO, $NRORGULTATU, $CDOPERULTATU);

        $produtosCampanha = $this->fidelityService->buscaProdutosCampanha($CDCAMPANHA);
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('ProdCampanhaRepo', $produtosCampanha));
    }

    public function alterarProduto(Request\Filter $request, Response $response){
        $params = $request->getFilterCriteria()->getConditions();

        $CDCAMPANHA      = $params[0]['value'];
        $CDPRODUTO       = $params[1]['value'];
        $IDPRODUTOGERA   = $params[2]['value'];
        $VRPONTOPROD     = $params[3]['value'];
        $DTINIVIGPROD    = $params[4]['value'];
        $DTFIMVIGPROD    = $params[5]['value'];
        $NRORG           = $params[6]['value'];
        $NRORGINCLUSAO   = $params[7]['value'];
        $CDOPERINCLUSAO  = $params[8]['value'];
        $NRORGULTATU     = $params[9]['value'];
        $CDOPERULTATU    = $params[10]['value'];

        $NRSEQPRODCAMP = $this->util->newCode('PRODCAMPANHA'.$CDCAMPANHA, '10');

        $checkProduto = $this->fidelityService->buscaProdCampanha($CDCAMPANHA, $CDPRODUTO);
        if(empty($checkProduto)){
            $this->fidelityService->incluirProduto($CDCAMPANHA, $NRSEQPRODCAMP, $CDPRODUTO, $IDPRODUTOGERA, $VRPONTOPROD, $DTINIVIGPROD, $DTFIMVIGPROD, $NRORG, $NRORGINCLUSAO, $CDOPERINCLUSAO, $NRORGULTATU, $CDOPERULTATU);

            $produtosCampanha = $this->fidelityService->buscaProdutosCampanha($CDCAMPANHA);
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('ProdCampanhaRepo', $produtosCampanha));
        }else{
           $this->fidelityService->alterarProduto($CDCAMPANHA, $NRSEQPRODCAMP, $CDPRODUTO, $IDPRODUTOGERA, $VRPONTOPROD, $DTINIVIGPROD, $DTFIMVIGPROD, $NRORG, $NRORGINCLUSAO, $NRORGULTATU, $CDOPERULTATU);

           $produtosCampanha = $this->fidelityService->buscaProdutosCampanha($CDCAMPANHA);
           $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('ProdCampanhaRepo', $produtosCampanha));
        }

    }

    public function inserirBrinde(Request\Filter $request, Response $response){
        $params = $request->getFilterCriteria()->getConditions();

        $CDPRODUTO      = $params[0]['value'];
        $DSBRINDE       = $params[1]['value'];
        $VRPONTOBRINDE  = $params[2]['value'];
        $CDCAMPANHA     = $params[3]['value'];
        $NRORG          = $params[4]['value'];
        $NRORGINCLUSAO  = $params[5]['value'];
        $CDOPERINCLUSAO = $params[6]['value'];
        $NRORGULTATU    = $params[7]['value'];
        $CDOPERULTATU   = $params[8]['value'];

        $this->fidelityService->inserirBrinde($CDPRODUTO, $DSBRINDE, $VRPONTOBRINDE, $CDCAMPANHA, $NRORG, $NRORGINCLUSAO, $CDOPERINCLUSAO, $NRORGULTATU, $CDOPERULTATU);

        $BrindesCampanha = $this->fidelityService->buscaBrindesCampanha($CDCAMPANHA);
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('BrindeCampanhaRepo', $BrindesCampanha));
    }

    public function alterarBrinde(Request\Filter $request, Response $response){
        $params = $request->getFilterCriteria()->getConditions();

        $CDPRODUTO      = $params[0]['value'];
        $DSBRINDE       = $params[1]['value'];
        $VRPONTOBRINDE  = $params[2]['value'];
        $CDCAMPANHA     = $params[3]['value'];
        $NRORG          = $params[4]['value'];
        $NRORGINCLUSAO  = $params[5]['value'];
        $CDOPERINCLUSAO = $params[6]['value'];
        $NRORGULTATU    = $params[7]['value'];
        $CDOPERULTATU   = $params[8]['value'];

        $checkBrinde = $this->fidelityService->buscaBrindeCampanha($CDCAMPANHA, $CDPRODUTO);
        if(empty($checkBrinde)){
            $this->fidelityService->inserirBrinde($CDPRODUTO, $DSBRINDE, $VRPONTOBRINDE, $CDCAMPANHA, $NRORG, $NRORGINCLUSAO, $CDOPERINCLUSAO, $NRORGULTATU, $CDOPERULTATU);

            $BrindesCampanha = $this->fidelityService->buscaBrindesCampanha($CDCAMPANHA);
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('BrindeCampanhaRepo', $BrindesCampanha));
        }else{
            $this->fidelityService->alterarBrinde($CDPRODUTO, $DSBRINDE, $VRPONTOBRINDE, $CDCAMPANHA, $NRORG, $NRORGINCLUSAO, $NRORGULTATU, $CDOPERULTATU);

            $BrindesCampanha = $this->fidelityService->buscaBrindesCampanha($CDCAMPANHA);
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('BrindeCampanhaRepo', $BrindesCampanha));
        }
    }

    public function buscaDadosCampanha(Request\Filter $request, Response $response){
        $params = $request->getFilterCriteria()->getConditions();
        $CDCAMPANHA = $params[0]['value'];

        $filiaisCampanha = $this->fidelityService->buscaFiliaisCampanha($CDCAMPANHA);
        $produtosCampanha = $this->fidelityService->buscaProdutosCampanha($CDCAMPANHA);
        $BrindesCampanha = $this->fidelityService->buscaBrindesCampanha($CDCAMPANHA);


        for($i = 0; $i < count($produtosCampanha); ++$i) {

           $produtosCampanha[$i]['DTINIVIGPROD'] = substr($produtosCampanha[$i]['DTINIVIGPROD'], 0, 10);
           $produtosCampanha[$i]['DTFIMVIGPROD'] = substr($produtosCampanha[$i]['DTFIMVIGPROD'], 0, 10);
        }

        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('FilialCampanhaRepo', $filiaisCampanha));
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('ProdCampanhaRepo', $produtosCampanha));
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('BrindeCampanhaRepo', $BrindesCampanha));
    }

    public function alterarCampanha(Request\Filter $request, Response $response){
        $params = $request->getFilterCriteria()->getConditions();

        $params =  $this->util->replaceParams($params);

        $CDCAMPANHA         = $params[0]['value'];
        $CDTPCAMPANHA       = $params[1]['value'];
        $DSCAMPANHA         = $params[2]['value'];
        $DTFIMVIGCAMP       = $params[3]['value'];
        $DTINIVIGCAMP       = $params[4]['value'];
        $IDUTILVOUCHER      = $params[5]['value'];
        $NMTPCAMPANHA       = $params[6]['value'];
        $NRDIASVALPONTO     = $params[7]['value'];
        $NRDIAVALVOUCHER    = $params[8]['value'];
        $VRPONTOVOUCHER     = $params[9]['value'];
        $CDPROMOCAODOTZ     = $params[10]['value'];
        $VRPESOCAMP         = $params[11]['value'];
        $VRPONTOCAMP        = $params[12]['value'];
        $VRVENDAINIDOTZ     = $params[13]['value'];
        $VRVENDAFINDOTZ     = $params[14]['value'];
        $NRORG              = $params[15]['value'];
        $NRORGINCLUSAO      = $params[16]['value'];
        $CDOPERINCLUSAO     = $params[17]['value'];
        $NRORGULTATU        = $params[18]['value'];
        $CDOPERULTATU       = $params[19]['value'];

        $message =$this->salesMessage->getMessage('alterado');
        $this->fidelityService->alterarCampanha($CDCAMPANHA, $CDTPCAMPANHA, $DSCAMPANHA, $DTFIMVIGCAMP, $DTINIVIGCAMP, $IDUTILVOUCHER, $NMTPCAMPANHA, $NRDIASVALPONTO, $NRDIAVALVOUCHER, $VRPONTOVOUCHER, $CDPROMOCAODOTZ, $VRPESOCAMP, $VRPONTOCAMP, $VRVENDAINIDOTZ, $VRVENDAFINDOTZ, $NRORG, $NRORGINCLUSAO, $CDOPERINCLUSAO, $NRORGULTATU, $CDOPERULTATU);
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('AlterarCampanhaRepo', array($message)));
    }

    public function alteraFilialCamapanha(Request\Filter $request, Response $response){
        $params = $request->getFilterCriteria()->getConditions();

        $CDCAMPANHA = $params[0]['value'];
        $CDFILIAL   = $params[1]['value'];
    }

     public function alteraProdCampanha(Request\Filter $request, Response $response){
        $params = $request->getFilterCriteria()->getConditions();

        $CDCAMPANHA     = $params[0]['value'];
        $CDPRODUTO      = $params[1]['value'];
        $NMPRODUTO      = $params[2]['value'];
        $DTINIVIGPROD   = $params[3]['value'];
        $DTFIMVIGPROD   = $params[4]['value'];
        $VRPONTOPROD    = $params[5]['value'];
    }

    public function alteraBrindeCampanha(Request\Filter $request, Response $response){
        $params = $request->getFilterCriteria()->getConditions();

        $CDCAMPANHA      = $params[0]['value'];
        $CDPRODUTO       = $params[0]['value'];
        $DSBRINDE        = $params[0]['value'];
        $VRPONTOBRINDE   = $params[0]['value'];
        $CDCAMPANHA      = $params[0]['value'];
    }

    public function deleteFilialCampanha(Request\Filter $request, Response $response){
        $params = $request->getFilterCriteria()->getConditions();

        $CDCAMPANHA = $params[0]['value'];
        $CDFILIAL   = $params[1]['value'];

        $this->fidelityService->deleteFilialCampanha($CDCAMPANHA, $CDFILIAL);
        $filiaisCampanha = $this->fidelityService->buscaFiliaisCampanha($CDCAMPANHA);
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('FilialCampanhaRepo', $filiaisCampanha));

    }

    public function deleteProdCamapanha(Request\Filter $request, Response $response){
        $params = $request->getFilterCriteria()->getConditions();

        $CDCAMPANHA = $params[0]['value'];
        $produtos   = $params[1]['value'];
        $sucessmsgs = array();
        $erromsgs = array();
        foreach ($produtos as $CDPRODUTO) {
        	$NRSEQPRODCAMP = $this->fidelityService->buscaNRSEQPRODCAMP($CDCAMPANHA, $CDPRODUTO);
	        $NRSEQPRODCAMP = $NRSEQPRODCAMP[0]['NRSEQPRODCAMP'];

	        $verificaBENEFICIOCAMP = $this->fidelityService->verificaBENEFICIOCAMP($NRSEQPRODCAMP, $CDCAMPANHA);
	        $PRODUTOSELECAO = $this->produtoService->buscaProdutoEspecifico($CDPRODUTO);
	        $PRODUTOSELECAO = $PRODUTOSELECAO[0]['PRODUTOSELECAO'];

	        if(empty($verificaBENEFICIOCAMP)){
	            $this->fidelityService->deleteProdCamapanha($CDCAMPANHA, $CDPRODUTO);
	            $message =$this->salesMessage->getMessage(60).$PRODUTOSELECAO.$this->salesMessage->getMessage(61);
	            array_push($sucessmsgs, $message);
	        }else{
	            $message =$this->salesMessage->getMessage(60).$PRODUTOSELECAO.$this->salesMessage->getMessage(21);
	            array_push($erromsgs, $message);
	        }
        }
        $resposta= array ('sucess' => $sucessmsgs, 'error'=> $erromsgs);
        $produtosCampanha = $this->fidelityService->buscaProdutosCampanha($CDCAMPANHA);
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('DeleteProdRepo', $resposta));
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('ProdCampanhaRepo', $produtosCampanha));

    }

    public function deleteBrindeCamapanha(Request\Filter $request, Response $response){
        $params = $request->getFilterCriteria()->getConditions();

        $CDCAMPANHA = $params[0]['value'];
        $CDPRODUTO  = $params[1]['value'];

        $this->fidelityService->deleteBrindeCamapanha($CDCAMPANHA, $CDPRODUTO);
        $BrindesCampanha = $this->fidelityService->buscaBrindesCampanha($CDCAMPANHA);
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('BrindeCampanhaRepo', $BrindesCampanha));

    }

    public function cadTipoCampanha(Request\Filter $request, Response $response){
         $params = $request->getFilterCriteria()->getConditions();

         $params =  $this->util->replaceParams($params);

         $NMTPCAMPANHA   = $params[0]['value'];
         $NRORG          = $params[1]['value'];
         $NRORGINCLUSAO  = $params[2]['value'];
         $CDOPERINCLUSAO = $params[3]['value'];
         $NRORGULTATU    = $params[4]['value'];
         $CDOPERULTATU   = $params[5]['value'];

         $CDTPCAMPANHA = $this->util->newCode('TPCAMPANHA', '5');

         $this->fidelityService->cadTipoCampanha($CDTPCAMPANHA, $NMTPCAMPANHA, $NRORG, $NRORGINCLUSAO, $CDOPERINCLUSAO, $NRORGULTATU, $CDOPERULTATU);
         $tiposCampanha = $this->fidelityService->tiposCampanha();
         $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('TiposCampanhaRepo', $tiposCampanha));
    }

    public function alterarTipoCampanha(Request\Filter $request, Response $response){
        $params = $request->getFilterCriteria()->getConditions();

        $CDTPCAMPANHA   = $params[0]['value'];
        $NMTPCAMPANHA   = $params[1]['value'];

        $this->fidelityService->alterarTipoCampanha($CDTPCAMPANHA, $NMTPCAMPANHA);
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('nothing', array(array('nothing' => 'nothing'))));
    }

    public function deleteTpCampanha(Request\Filter $request, Response $response){
        $params = $request->getFilterCriteria()->getConditions();

        $CDTPCAMPANHA = $params[0]['value'];

        $checkUtilTPCampanha = $this->fidelityService->verificaUtilTPCampanha($CDTPCAMPANHA);

        if(empty($checkUtilTPCampanha)){
            $this->fidelityService->deleteTpCampanha($CDTPCAMPANHA);
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('nothing', array(array('nothing' => 'nothing'))));
        }else{
            $response->addMessage(new Message($this->salesMessage->getMessage(11)));
        }
    }

    public function filtrarMovimento(Request\Filter $request, Response $response){
        $params = $request->getFilterCriteria()->getConditions();

        $CDCAMPANHA   = $params[0]['value'];
        $CDCLIENTE    = $params[1]['value'];
        $CDCONSUMIDOR = $params[2]['value'];
        $IDCAMPANHA   = $params[3]['value'];

        $movimento = $this->fidelityService->filtrarMovimento($CDCAMPANHA, $CDCLIENTE, $CDCONSUMIDOR, $IDCAMPANHA);

        for($i = 0; $i < count($movimento); ++$i) {

           if($movimento[$i]['IDTPMOVCONS'] == 'C'){
                $movimento[$i]['IDTPMOVCONS'] = 'crédito';
           }else if($movimento[$i]['IDTPMOVCONS'] == 'D'){
                $movimento[$i]['IDTPMOVCONS'] = 'débito';
           }

           $movimento[$i]['DTVALIDAPONTO'] = substr($movimento[$i]['DTVALIDAPONTO'], 0, 10);
           $movimento[$i]['DTVALIDAPONTO'] = $this->util->formataDataBr($movimento[$i]['DTVALIDAPONTO']);
        }

        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('FiltrarMovimentoRepo', $movimento));

    }

    public function filtrarMovimentoBeneficio(Request\Filter $request, Response $response){
        $params = $request->getFilterCriteria()->getConditions();

        $CDCAMPANHA    = $params[0]['value'];
        $CDCLIENTE     = $params[1]['value'];
        $CDCONSUMIDOR  = $params[2]['value'];
        $NRSEQPRODCAMP = $params[3]['value'];

        //busca todos os beneficios relacionados a este produto(para o poup de adicionar)

        $beneficiosCampanha = $this->buscaBeneficiosProdCampanha($CDCAMPANHA, $NRSEQPRODCAMP);
        
        //BUSCA MOVIMENTO DE BENEFICIOS UTILIZADOS

        $movimento = $this->fidelityService->filtrarMovimentoBeneficio($CDCAMPANHA, $CDCLIENTE, $CDCONSUMIDOR);

        for($i = 0; $i < count($movimento); ++$i) {
            if($movimento[$i]['IDTPBENEFICIO'] == 'P'){
                $movimento[$i]['IDTPBENEFICIO'] = 'DESCONTO PERCENTUAL';
            }else{
                $movimento[$i]['IDTPBENEFICIO'] = 'DESCONTO VALOR';
            }

              $movimento[$i]['DTINCLUSAO']       = substr($movimento[$i]['DTINCLUSAO'], 0, 10);
              $movimento[$i]['DTINCLUSAO']       = $this->util->formataDataBr($movimento[$i]['DTINCLUSAO']);

              $movimento[$i]['DTUTBENECONS']     = substr($movimento[$i]['DTUTBENECONS'], 0, 10);
              $movimento[$i]['DTUTBENECONS']     = $this->util->formataDataBr($movimento[$i]['DTUTBENECONS']);
            
        }

        $beneficiosDisponiveis = $this->fidelityService->buscaBeneficiosDisponiveis($CDCAMPANHA, $CDCLIENTE, $CDCONSUMIDOR, $NRSEQPRODCAMP);
        for($i = 0; $i < count($beneficiosDisponiveis); ++$i) {

           if($beneficiosDisponiveis[$i]['IDTPBENEFICIO'] == 'P'){
                $beneficiosDisponiveis[$i]['LABEL'] = $beneficiosDisponiveis[$i]['NRSEQBENEFICIO'] .' DESCONTO PERCENTUAL '. $beneficiosDisponiveis[$i]['VRBENEFICIO'].'%' ;
           }else{
                $beneficiosDisponiveis[$i]['LABEL'] = $beneficiosDisponiveis[$i]['NRSEQBENEFICIO'] .' DESCONTO VALOR '. $this->util->formataDinheiro($beneficios[$i]['VRBENEFICIO']);
           }

        }

        $beneficios = $this->fidelityService->buscaBeneficioCampanha($CDCAMPANHA);

        for($i = 0; $i < count($beneficios); ++$i) {

           if($beneficios[$i]['IDTPBENEFICIO'] == 'P'){
                $beneficios[$i]['DESCRICAO'] = $beneficios[$i]['NRSEQBENEFICIO'] .' - DESCONTO PERCENTUAL '. $beneficios[$i]['VRBENEFICIO'].'%' ;
           }else{
                $beneficios[$i]['DESCRICAO'] = $beneficios[$i]['NRSEQBENEFICIO'] .' - DESCONTO VALOR '. $this->util->formataDinheiro($beneficios[$i]['VRBENEFICIO']);
           }

        }

        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('BuscaBeneCampRepo', $beneficiosCampanha));
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('BenDisponiveisRepo', $beneficiosDisponiveis));
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('FiltraMovBeneRepo', $movimento));
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('BuscaBeneCampManRepo', $beneficios));

    }

    public function filtrarMovData(Request\Filter $request, Response $response){
         $params = $request->getFilterCriteria()->getConditions();

        $CDCAMPANHA   = $params[0]['value'];
        $CDCLIENTE    = $params[1]['value'];
        $CDCONSUMIDOR = $params[2]['value'];
        $IDCAMPANHA   = $params[3]['value'];
        $DTINICIO     = $params[4]['value'];

        $movimento = $this->fidelityService->filtrarMovData($CDCAMPANHA, $CDCLIENTE, $CDCONSUMIDOR, $IDCAMPANHA, $DTINICIO);

        for($i = 0; $i < count($movimento); ++$i) {

           if($movimento[$i]['IDTPMOVCONS'] == 'C'){
                $movimento[$i]['IDTPMOVCONS'] = 'crédito';
           }else if($movimento[$i]['IDTPMOVCONS'] == 'D'){
                $movimento[$i]['IDTPMOVCONS'] = 'débito';
           }
        }

        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('FiltrarMovDataRepo', $movimento));
    }

    public function gravarManutencao(Request\Filter $request, Response $response){
        $params = $request->getFilterCriteria()->getConditions();

        $CDCAMPANHA      = $params[0]['value'];
        $CDCLIENTE       = $params[1]['value'];
        $CDCONSUMIDOR    = $params[2]['value'];
        $IDTPMOVCONS     = $params[3]['value'];
        $VRMOVPONTOCONS  = $params[4]['value'];
        $DSOBSMOVPTOCONS = $params[5]['value'];
        $DTVALIDAPONTO   = $params[6]['value'];
        $NRORG           = $params[7]['value'];
        $NRORGINCLUSAO   = $params[8]['value'];
        $NRORGULTATU     = $params[9]['value'];
        $CDOPERULTATU    = $params[10]['value'];
        $CDOPERINCLUSAO  = $params[11]['value'];

        $NRSEQMOVCONS = $this->util->newCode('MOVPONTOCONS'.$CDCAMPANHA.$CDCLIENTE.$CDCONSUMIDOR, '10');

        $dataAtual = getdate();
        $dataAtual =  $dataAtual["mday"].str_pad($dataAtual["mon"], 2, "0", STR_PAD_LEFT).$dataAtual["year"];
        $dataValidade = str_replace('/', "", $DTVALIDAPONTO);

        if(($dataValidade == null && $IDTPMOVCONS == 'D') || ($dataValidade != null && $IDTPMOVCONS == 'D') || ($this->util->compararMenorData($dataAtual, $dataValidade))){
            if($IDTPMOVCONS == 'C'){
                $VRSALDOCONS = $VRMOVPONTOCONS;
                $this->fidelityService->gravarManutencao($CDCAMPANHA, $CDCLIENTE, $CDCONSUMIDOR, $IDTPMOVCONS, $VRMOVPONTOCONS, $VRSALDOCONS, $NRSEQMOVCONS, $DSOBSMOVPTOCONS, $DTVALIDAPONTO, $NRORG, $NRORGINCLUSAO, $NRORGULTATU, $CDOPERULTATU, $CDOPERINCLUSAO);
                $this->fidelityService->atualizaVRSALDOCONS($CDCAMPANHA, $CDCLIENTE, $CDCONSUMIDOR, $NRSEQMOVCONS, $VRMOVPONTOCONS);

                $IDCAMPANHA = $this->fidelityService->buscaMecanica($CDCAMPANHA);
                $IDCAMPANHA = $IDCAMPANHA[0]['IDCAMPANHA'];

                    if($IDCAMPANHA == 'P'){
                        Self::geraVoucher($CDCAMPANHA, $CDCLIENTE, $CDCONSUMIDOR);
                    }


                $response->addMessage(new Message($this->salesMessage->getMessage(12)));
                $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('nothing', array(array('nothing' => 'nothing'))));
            }else{

                $SALDO = $this->fidelityService->buscaSaldo($CDCAMPANHA, $CDCLIENTE, $CDCONSUMIDOR);
                $SALDO  = $SALDO[0]['VRSALDOCONS'];
                $MOVIMENTACAO = $VRMOVPONTOCONS;

                if($SALDO - $MOVIMENTACAO >= 0){

                    while($MOVIMENTACAO > 0){
                        $creditomaisAntigo = $this->fidelityService->creditomaisAntigo($CDCAMPANHA, $CDCLIENTE, $CDCONSUMIDOR);

                        $VRSALDOANTIGO = $creditomaisAntigo[0]['VRSALDOCONS'];;
                        $NRSEQMOVCONSupdate = $creditomaisAntigo[0]['NRSEQMOVCONS'];

                        if(($MOVIMENTACAO - $VRSALDOANTIGO) >= 0){
                            $VRSALDOCONSupdate = 0;
                            $this->fidelityService->atualizaVRSALDOCONS($CDCAMPANHA, $CDCLIENTE, $CDCONSUMIDOR, $NRSEQMOVCONSupdate, $VRSALDOCONSupdate);
                            $MOVIMENTACAO = $MOVIMENTACAO - $VRSALDOANTIGO;

                        }else if($MOVIMENTACAO - $VRSALDOANTIGO < 0){
                            $VRSALDOCONSupdate = $VRSALDOANTIGO - $MOVIMENTACAO;
                            $this->fidelityService->atualizaVRSALDOCONS($CDCAMPANHA, $CDCLIENTE, $CDCONSUMIDOR, $NRSEQMOVCONSupdate, $VRSALDOCONSupdate);
                            $MOVIMENTACAO = 0;
                        }
                    }
                    $VRSALDOCONS  = 0;
                    $this->fidelityService->gravarManutencao($CDCAMPANHA, $CDCLIENTE, $CDCONSUMIDOR, $IDTPMOVCONS, $VRMOVPONTOCONS, $VRSALDOCONS, $NRSEQMOVCONS, $DSOBSMOVPTOCONS, $DTVALIDAPONTO, $NRORG, $NRORGINCLUSAO, $NRORGULTATU, $CDOPERULTATU, $CDOPERINCLUSAO);

                    $response->addMessage(new Message($this->salesMessage->getMessage(12)));
                    $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('nothing', array(array('nothing' => 'nothing'))));
                }else{
                     $response->addMessage(new Message($this->salesMessage->getMessage(13)));
                }
            }
        }else{
            $response->addMessage(new Message($this->salesMessage->getMessage(15)));
        }
    }

    public function carregaVouchers(Request\Filter $request, Response $response){
        $params = $request->getFilterCriteria()->getConditions();

        $CDCAMPANHA     = $params[0]['value'];
        $CDCLIENTE      = $params[1]['value'];
        $CDCONSUMIDOR   = $params[2]['value'];

        $dadosVouchers = $this->fidelityService->carregaVouchers($CDCAMPANHA, $CDCLIENTE, $CDCONSUMIDOR);

        for($i = 0; $i < count($dadosVouchers); ++$i) {

            $dadosVouchers[$i]['DTGERVOUCHER'] = substr($dadosVouchers[$i]['DTGERVOUCHER'], 0, 10);
            $dadosVouchers[$i]['DTGERVOUCHER'] = $this->util->formataDataBr($dadosVouchers[$i]['DTGERVOUCHER']);

            $dadosVouchers[$i]['DTVALVOUCHER'] = substr($dadosVouchers[$i]['DTVALVOUCHER'], 0, 10);
            $dadosVouchers[$i]['DTVALVOUCHER'] = $this->util->formataDataBr($dadosVouchers[$i]['DTVALVOUCHER']);

            $dadosVouchers[$i]['DTUTIVOUCHER'] = substr($dadosVouchers[$i]['DTUTIVOUCHER'], 0, 10);
            $dadosVouchers[$i]['DTUTIVOUCHER'] = $this->util->formataDataBr($dadosVouchers[$i]['DTUTIVOUCHER']);
        }

        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('CarregaVouchersRepo', $dadosVouchers));
    }

    public function buscaSaldo(Request\Filter $request, Response $response){
        $params = $request->getFilterCriteria()->getConditions();

        $CDCAMPANHA   = $params[0]['value'];
        $CDCLIENTE    = $params[1]['value'];
        $CDCONSUMIDOR = $params[2]['value'];

        $saldo =  $this->fidelityService->buscaSaldo($CDCAMPANHA, $CDCLIENTE, $CDCONSUMIDOR);
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('BuscaSaldoRepo', $saldo));
    }

    public function filtrarConsulta(Request\Filter $request, Response $response){
        $params = $request->getFilterCriteria()->getConditions();
        
        $CDCAMPANHA   = $params[0]['value'];

        $DADOSCAMPANHA   = $this->fidelityService->dadosCampanha($CDCAMPANHA);

        $CAMPANHASELECAO = $DADOSCAMPANHA[0]['CAMPANHASELECAO'];
        $IDCAMPANHA      = $DADOSCAMPANHA[0]['IDCAMPANHA'];

        $DTINIVIGCAMP    = $DADOSCAMPANHA[0]['DTINIVIGCAMP'];
        $DTINIVIGCAMP    = substr($DTINIVIGCAMP, 0, 10);


        $DTFIMVIGCAMP    = $DADOSCAMPANHA[0]['DTFIMVIGCAMP'];
        $DTFIMVIGCAMP    = substr($DTFIMVIGCAMP, 0, 10);

        
        if($IDCAMPANHA != 'C'){

            $VRTOTVENDAS = $this->fidelityService->vrtotvendas($CDCAMPANHA, $DTINIVIGCAMP, $DTFIMVIGCAMP);
            $VRTOTVENDAS = $VRTOTVENDAS[0]['VRTOTVENDAS'];

            $NRCONSUMIDORES = $this->fidelityService->qtdConumidores($CDCAMPANHA);
            $NRCONSUMIDORES = $NRCONSUMIDORES[0]['NRCONSUMIDORES'];

            $dadosBeneficio     = $this->fidelityService->dadosBeneficio($CDCAMPANHA, $DTINIVIGCAMP, $DTFIMVIGCAMP, $NRCONSUMIDORES);
            $NRBENEFICIADOS     = $dadosBeneficio[0]['NRBENEFICIADOS'];
            $NRNAOBENEFICIADOS  = $dadosBeneficio[0]['NRNAOBENEFICIADOS'];

            $dadosClienteCampanha = $this->clienteService->buscaDadosClienteCampanha($CDCAMPANHA);

            $dadosResgBrinde = $this->fidelityService->dadosResgBrinde($CDCAMPANHA, $DTINIVIGCAMP, $DTFIMVIGCAMP);
            $NRBRINDERESG    = $dadosResgBrinde[0]['NRBRINDERESG'];
            $VRTOTBRINDERESG = $dadosResgBrinde[0]['VRTOTBRINDERESG'];

            $dadosBrindesResgatados = $this->fidelityService->buscaBrindesResgatados($CDCAMPANHA, $DTINIVIGCAMP, $DTFIMVIGCAMP);

            $params = array(
                array(
                    'CDCAMPANHA'        => $CDCAMPANHA,
                    'CAMPANHASELECAO'   => $CAMPANHASELECAO,
                    'IDCAMPANHA'        => $IDCAMPANHA,
                    'DTINIVIGCAMP'      => $DTINIVIGCAMP,
                    'DTFIMVIGCAMP'      => $DTFIMVIGCAMP,
                    'VRTOTVENDAS'       => $VRTOTVENDAS,
                    'NRCONSUMIDORES'    => $NRCONSUMIDORES,
                    'NRBENEFICIADOS'    => $NRBENEFICIADOS,
                    'NRNAOBENEFICIADOS' => $NRNAOBENEFICIADOS,
                    'NRBRINDERESG'      => $NRBRINDERESG,
                    'VRTOTBRINDERESG'   => $VRTOTBRINDERESG
                )
            );

            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('FiltrarConsultaRepo', $params));
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('ClienteCampanhaRepo', $dadosClienteCampanha));
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('BrindeResgatadoRepo', $dadosBrindesResgatados));
        }else{

            $VRTOTVENDAS = $this->fidelityService->vrtotvendasCampBeneficio($CDCAMPANHA, $DTINIVIGCAMP, $DTFIMVIGCAMP);
            $VRTOTVENDAS = $VRTOTVENDAS[0]['VRTOTVENDAS'];

            $NRCONSUMIDORES = $this->fidelityService->qtdConumidoresCampBeneficio($CDCAMPANHA);
            $NRCONSUMIDORES = $NRCONSUMIDORES[0]['NRCONSUMIDORES'];

            $dadosBeneficio     = $this->fidelityService->dadosBeneficioCampBeneficio($CDCAMPANHA, $DTINIVIGCAMP, $DTFIMVIGCAMP, $NRCONSUMIDORES);
            $NRBENEFICIADOS     = $dadosBeneficio[0]['NRBENEFICIADOS'];
            $NRNAOBENEFICIADOS  = $dadosBeneficio[0]['NRNAOBENEFICIADOS'];

            $dadosClienteCampanha = $this->clienteService->buscaDadosClienteCampBeneficio($CDCAMPANHA);

            $QTDBENEUTIL = $this->fidelityService->buscaQtdBeneUtil($CDCAMPANHA);
            $QTDBENEUTIL = $QTDBENEUTIL[0]['QTDBENEUTIL'];

            $QTDBENENAOUTIL = $this->fidelityService->buscaQtdBeneNaoUtil($CDCAMPANHA);
            $QTDBENENAOUTIL = $QTDBENENAOUTIL[0]['QTDBENENAOUTIL'];

            $TOTDESCCAMP = $this->fidelityService->buscaTotalDescCampanha($CDCAMPANHA);
            $TOTDESCCAMP = $TOTDESCCAMP[0]['TOTDESCCAMP'];

            $params = array(
                array(
                    'CDCAMPANHA'        => $CDCAMPANHA,
                    'CAMPANHASELECAO'   => $CAMPANHASELECAO,
                    'IDCAMPANHA'        => $IDCAMPANHA,
                    'DTINIVIGCAMP'      => $DADOSCAMPANHA[0]['DTINIVIGCAMP'],
                    'DTFIMVIGCAMP'      => $DADOSCAMPANHA[0]['DTFIMVIGCAMP'],
                    'VRTOTVENDAS'       => $VRTOTVENDAS,
                    'NRCONSUMIDORES'    => $NRCONSUMIDORES,
                    'NRBENEFICIADOS'    => $NRBENEFICIADOS,
                    'NRNAOBENEFICIADOS' => $NRNAOBENEFICIADOS,
                    'QTDBENEUTIL'       => $QTDBENEUTIL,
                    'QTDBENENAOUTIL'    => $QTDBENENAOUTIL,
                    'TOTDESCCAMP'       => $TOTDESCCAMP
                )
            );  
           
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('FiltrarConsultaRepo', $params));
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('ClienteCampanhaRepo', $dadosClienteCampanha));
        }

    }

    public function buscaConsCampanha(Request\Filter $request, Response $response){
        $params = $request->getFilterCriteria()->getConditions();
        $CDCAMPANHA = $params[0]['value'];
        $CDCLIENTE  = $params[1]['value'];

        $buscaVigCamp = $this->fidelityService->buscaVigCamp($CDCAMPANHA);

        $DTINIVIGCAMP = $buscaVigCamp[0]['DTINIVIGCAMP'];
        $DTINIVIGCAMP    = substr($DTINIVIGCAMP, 0, 10);
        $DTINIVIGCAMP    = $this->util->formataDataBr($DTINIVIGCAMP);

        $DTFIMVIGCAMP = $buscaVigCamp[0]['DTFIMVIGCAMP'];
        $DTFIMVIGCAMP    = substr($DTFIMVIGCAMP, 0, 10);
        $DTFIMVIGCAMP    = $this->util->formataDataBr($DTFIMVIGCAMP);

        $dadosConsCampanha = $this->consumidorService->buscaConsCampanha($CDCAMPANHA, $CDCLIENTE, $DTINIVIGCAMP, $DTFIMVIGCAMP);
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('ConsCampanhaRepo', $dadosConsCampanha));
    }
    
    public function buscaCampanhaBrinde(Request\Filter $request, Response $response){
        $params = $request->getFilterCriteria()->getConditions();

        $CDCLIENTE    = $params[0]['value'];
        $CDCONSUMIDOR = $params[1]['value'];

        $dadosCampBrinde = $this->fidelityService->buscaCampanhaBrinde($CDCLIENTE, $CDCONSUMIDOR);

        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('BuscaCampBrindeRepo', $dadosCampBrinde));
    }

    public function buscaCampanhaDesconto(Request\Filter $request, Response $response){
        $params = $request->getFilterCriteria()->getConditions();

        $CDCLIENTE    = $params[0]['value'];
        $CDCONSUMIDOR = $params[1]['value'];

        $dadosCampDesconto = $this->fidelityService->buscaCampanhaDesconto($CDCLIENTE, $CDCONSUMIDOR);

        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('BuscaCampDescRepo', $dadosCampDesconto));
    }

    public function buscaCampanhaBeneficios(Request\Filter $request, Response $response){
        $params = $this->util->getParamsAsArray($request);
        $NRORG        = $params['NRORG'];
        $CDCLIENTE    = $params['CDCLIENTE'];
        $CDCONSUMIDOR = $params['CDCONSUMIDOR'];

        $dadosCampBeneficio = $this->fidelityService->buscaCampanhaBeneficios($CDCLIENTE, $CDCONSUMIDOR, $NRORG);

        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('BuscaCampBeneRepo', $dadosCampBeneficio));
    }

    public function buscaBeneficios(Request\Filter $request, Response $response){
        $beneficios = $this->fidelityService->buscaBeneficios();

        for($i = 0; $i < count($beneficios); ++$i) {

           if($beneficios[$i]['IDTPBENEFICIO'] == 'P'){
                $beneficios[$i]['IDTPBENEFICIOLABEL'] = 'DESCONTO PERCENTUAL';
           }else{
                $beneficios[$i]['IDTPBENEFICIOLABEL'] = 'DESCONTO VALOR';
           }
           if($beneficios[$i]['IDTPATIVABENEFICIO'] == '1'){
                $beneficios[$i]['IDTPATIVABENEFICIOLABEL'] = 'ATIVAÇÃO CARTÃO';
           }else{
                $beneficios[$i]['IDTPATIVABENEFICIOLABEL'] = 'COMPRA CARTÃO';
           }
        }

        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('BuscaBeneficiosRepo', $beneficios));
    }

    public function buscaBeneficio(Request\Filter $request, Response $response){
        $params = $request->getFilterCriteria()->getConditions();
        $NRSEQBENEFICIO      = $params[0]['value'];

        $beneficios = $this->fidelityService->buscaBeneficio($NRSEQBENEFICIO);

        for($i = 0; $i < count($beneficios); ++$i) {

           if($beneficios[$i]['IDTPBENEFICIO'] == 'P'){
                $beneficios[$i]['IDTPBENEFICIOLABEL'] = 'DESCONTO PERCENTUAL';
           }else{
                $beneficios[$i]['IDTPBENEFICIOLABEL'] = 'DESCONTO VALOR';
           }

           if($beneficios[$i]['IDTPATIVABENEFICIO'] == '1'){
                $beneficios[$i]['IDTPATIVABENEFICIOLABEL'] = 'ATIVAÇÃO CARTÃO';
           }else{
                $beneficios[$i]['IDTPATIVABENEFICIOLABEL'] = 'COMPRA CARTÃO';
           }


        }

        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('BuscaBeneficioRepo', $beneficios));
    }

    public function cadBeneficio(Request\Filter $request, Response $response){
        $params = $request->getFilterCriteria()->getConditions();
        

        $IDTPBENEFICIO      = $params[0]['value'];
        $VRBENEFICIO        = $params[1]['value'];
        $IDTPATIVABENEFICIO = $params[2]['value'];
        $NRORG              = $params[3]['value'];
        $NRORGINCLUSAO      = $params[4]['value'];
        $CDOPERINCLUSAO     = $params[5]['value'];
        $NRORGULTATU        = $params[6]['value'];
        $CDOPERULTATU       = $params[7]['value'];
        $DSBENEFICIO        = $params[8]['value'];
        $QTDMAXDIACOMPRA    = $params[9]['value'];
        $QTDMAXDIASUBSEQ    = $params[10]['value'];

        $NRSEQBENEFICIO = $this->util->newCode('BENEFICIOFOS', '10');

        $this->fidelityService->cadBeneficio($NRSEQBENEFICIO, $IDTPBENEFICIO, $VRBENEFICIO, $IDTPATIVABENEFICIO, $NRORG, $NRORGINCLUSAO, $CDOPERINCLUSAO, $NRORGULTATU, $CDOPERULTATU, $DSBENEFICIO, $QTDMAXDIACOMPRA, $QTDMAXDIASUBSEQ);

        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('nothing', array(array('nothing' => 'nothing'))));
    }

    public function alterarBeneficio(Request\Filter $request, Response $response){
        $params = $request->getFilterCriteria()->getConditions();

        $NRSEQBENEFICIO     = $params[0]['value'];
        $IDTPBENEFICIO      = $params[1]['value'];
        $VRBENEFICIO        = $params[2]['value'];
        $IDTPATIVABENEFICIO = $params[3]['value'];
        $NRORG              = $params[4]['value'];
        $NRORGINCLUSAO      = $params[5]['value'];
        $CDOPERINCLUSAO     = $params[6]['value'];
        $NRORGULTATU        = $params[7]['value'];
        $CDOPERULTATU       = $params[8]['value'];
        $DSBENEFICIO        = $params[9]['value'];
        $QTDMAXDIACOMPRA    = $params[10]['value'];
        $QTDMAXDIASUBSEQ    = $params[11]['value'];

        $verificaUtilbeneficio =  $this->fidelityService->verificarUtilbeneficio($NRSEQBENEFICIO);

        if(empty($verificaUtilbeneficio)){
            $this->fidelityService->alterarBeneficio($NRSEQBENEFICIO, $IDTPBENEFICIO, $VRBENEFICIO, $IDTPATIVABENEFICIO, $NRORG, $NRORGINCLUSAO, $CDOPERINCLUSAO, $NRORGULTATU, $CDOPERULTATU, $DSBENEFICIO, $QTDMAXDIACOMPRA, $QTDMAXDIASUBSEQ);
        }else{
             $this->fidelityService->alteraDsbeneficioQtdmaxdiasubseqQtdmaxdiacompra($NRSEQBENEFICIO, $DSBENEFICIO, $QTDMAXDIACOMPRA, $QTDMAXDIASUBSEQ);
             $response->addMessage(new Message($this->salesMessage->getMessage(86)));
        }

        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('nothing', array(array('nothing' => 'nothing'))));
    }

    public function deletarBeneficio(Request\Filter $request, Response $response){
        $params = $request->getFilterCriteria()->getConditions();

        $NRSEQBENEFICIO     = $params[0]['value'];

        $verificaUtilbeneficio =  $this->fidelityService->verificarUtilbeneficio($NRSEQBENEFICIO);

        if(empty($verificaUtilbeneficio)){
            $this->fidelityService->deletarBeneficio($NRSEQBENEFICIO);
        }else{
            $response->addMessage(new Message($this->salesMessage->getMessage(18)));
        }

        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('nothing', array(array('nothing' => 'nothing'))));
    }

    public function atualizaTelaBeneficio(Request\Filter $request, Response $response){

        $campanhas = $this->fidelityService->buscaCampanhaBeneficio();

        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('BuscaBeneficiosRepo', $beneficios));
    }

    public function buscaBeneficiosCampanha(Request\Filter $request, Response $response){
        $params = $request->getFilterCriteria()->getConditions();

        $CDCAMPANHA = $params[0]['value'];
        $CDPRODUTO  = $params[1]['value'];

        $NRSEQPRODCAMP = $this->fidelityService->buscaNRSEQPRODCAMP($CDCAMPANHA, $CDPRODUTO);
        $NRSEQPRODCAMP = $NRSEQPRODCAMP[0]['NRSEQPRODCAMP'];
        $beneficiosCampanha = $this->buscaBeneficiosProdCampanha($CDCAMPANHA, $NRSEQPRODCAMP);
        $beneficios = $this->fidelityService->buscaBeneficios();

        for($i = 0; $i < count($beneficios); ++$i) {
            if($beneficios[$i]['IDTPBENEFICIO'] == 'P'){
                $beneficios[$i]['DESCRICAO'] = $beneficios[$i]['NRSEQBENEFICIO'] .' - DESCONTO PERCENTUAL '. $beneficios[$i]['VRBENEFICIO'].'%' ;
            }else{
                $beneficios[$i]['DESCRICAO'] = $beneficios[$i]['NRSEQBENEFICIO'] .' - DESCONTO VALOR '. $this->util->formataDinheiro($beneficios[$i]['VRBENEFICIO']);
            }
        }
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('BuscaBeneCampRepo', $beneficiosCampanha));
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('BuscaBeneficiosRepo', $beneficios));

    }

    public function buscaBeneficiosProdCampanha($CDCAMPANHA, $NRSEQPRODCAMP){
        $beneficiosCampanha = $this->fidelityService->buscaBeneficiosCampanha($CDCAMPANHA, $NRSEQPRODCAMP);

        for($i = 0; $i < count($beneficiosCampanha); ++$i) {
            if($beneficiosCampanha[$i]['IDTPATIVABENEFICIO'] == '1'){
                $beneficiosCampanha[$i]['IDTPATIVABENEFICIO'] = 'ATIVAÇÃO DO CARTÃO';
            }else{
                $beneficiosCampanha[$i]['IDTPATIVABENEFICIO'] = 'COMPRA DO CARTÃO';
            }

            if($beneficiosCampanha[$i]['IDTPBENEFICIO'] == 'P'){
                $beneficiosCampanha[$i]['LABELTPBENEFICIO'] = 'DESCONTO PERCENTUAL';
                $beneficiosCampanha[$i]['DESCRICAO'] = $beneficiosCampanha[$i]['NRSEQBENEFICIO'] .' - DESCONTO PERCENTUAL '. $beneficiosCampanha[$i]['VRBENEFICIO'].'%' ;
            }else{
                $beneficiosCampanha[$i]['LABELTPBENEFICIO'] = 'DESCONTO VALOR';
                $beneficiosCampanha[$i]['DESCRICAO'] = $beneficiosCampanha[$i]['NRSEQBENEFICIO'] .' - DESCONTO VALOR '. $this->util->formataDinheiro($beneficiosCampanha[$i]['VRBENEFICIO']);
            }
        }
        return $beneficiosCampanha;
    }

    public function cadBeneficioCampanha(Request\Filter $request, Response $response){
        $params = $request->getFilterCriteria()->getConditions();

        $CDCAMPANHA         = $params[0]['value'];
        $NRSEQBENEFICIO     = $params[1]['value'];
        $CDPRODUTO          = $params[2]['value'];
        $NRDIASVALBENECAMP  = $params[3]['value'];
        $QTBENEFICIOCAMP    = $params[4]['value'];
        $NRORG              = $params[5]['value'];
        $NRORGINCLUSAO      = $params[6]['value'];
        $CDOPERINCLUSAO     = $params[7]['value'];
        $NRORGULTATU        = $params[8]['value'];
        $CDOPERULTATU       = $params[9]['value'];

        $NRSEQPRODCAMP = $this->fidelityService->buscaNRSEQPRODCAMP($CDCAMPANHA, $CDPRODUTO);
        
        $NRSEQPRODCAMP = $NRSEQPRODCAMP[0]['NRSEQPRODCAMP'];

        $utilizacaoBeneficio = $this->fidelityService->verificaUsobeneCamp($CDCAMPANHA, $NRSEQPRODCAMP, $NRSEQBENEFICIO);

        if(empty($utilizacaoBeneficio)){
            $this->fidelityService->cadBeneficioCampanha($CDCAMPANHA, $NRSEQBENEFICIO, $NRSEQPRODCAMP, $NRDIASVALBENECAMP, $QTBENEFICIOCAMP, $NRORG, $NRORGINCLUSAO, $CDOPERINCLUSAO, $NRORGULTATU, $CDOPERULTATU);
        }else{
            $response->addMessage(new Message($this->salesMessage->getMessage(19)));
        }

        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('nothing', array(array('nothing' => 'nothing'))));
    }

    public function buscaProdBeneficio(Request\Filter $request, Response $response){
        $params = $request->getFilterCriteria()->getConditions();

        $CDCAMPANHA     = $params[0]['value'];
        $NRSEQBENEFICIO = $params[1]['value'];
        $NRSEQPRODCAMP  = $params[2]['value'];

        $prodbeneficio =  $this->fidelityService->buscaProdBeneficio($CDCAMPANHA, $NRSEQBENEFICIO, $NRSEQPRODCAMP);

        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('BuscaProdBeneRepo', $prodbeneficio));
    }

    public function cadProdBeneCamp(Request\Filter $request, Response $response){
        $params = $request->getFilterCriteria()->getConditions();

        $CDCAMPANHA     = $params[0]['value'];
        $NRSEQPRODCAMP  = $params[1]['value'];
        $NRSEQBENEFICIO = $params[2]['value'];
        $CDPRODUTO      = $params[3]['value'];
        $NRORG          = $params[4]['value'];
        $NRORGINCLUSAO  = $params[5]['value'];
        $CDOPERINCLUSAO = $params[6]['value'];
        $NRORGULTATU    = $params[7]['value'];
        $CDOPERULTATU   = $params[8]['value'];

        $verificaProdInclusao = $this->fidelityService->verificaProdBeneCamp($CDCAMPANHA, $NRSEQPRODCAMP, $NRSEQBENEFICIO, $CDPRODUTO);

        if(empty($verificaProdInclusao)){
            $this->fidelityService->cadProdBeneCamp($CDCAMPANHA, $NRSEQPRODCAMP, $NRSEQBENEFICIO, $CDPRODUTO, $NRORG, $NRORGINCLUSAO, $CDOPERINCLUSAO, $NRORGULTATU, $CDOPERULTATU);
        }else{
            $response->addMessage(new Message($this->salesMessage->getMessage(20)));
        }

        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('nothing', array(array('nothing' => 'nothing'))));
    }

    public function deletarProdBeneCamp(Request\Filter $request, Response $response){
        $params = $request->getFilterCriteria()->getConditions();

        $CDCAMPANHA     = $params[0]['value'];
        $CDPRODUTO      = $params[1]['value'];
        $NRSEQBENEFICIO = $params[2]['value'];
        $NRSEQPRODCAMP  = $params[3]['value'];

        $this->fidelityService->deletarProdBeneCamp($CDCAMPANHA, $CDPRODUTO, $NRSEQBENEFICIO, $NRSEQPRODCAMP);

        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('nothing', array(array('nothing' => 'nothing'))));
    }

    public function deletarBeneficioCamp(Request\Filter $request, Response $response){
        $params = $request->getFilterCriteria()->getConditions();

        $CDCAMPANHA     = $params[0]['value'];
        $NRSEQBENEFICIO = $params[1]['value'];
        $NRSEQPRODCAMP  = $params[2]['value'];

        $utilizacaoBeneficio = $this->fidelityService->verificaProdutoComBeneficio($CDCAMPANHA, $NRSEQPRODCAMP, $NRSEQBENEFICIO);

        if(empty($utilizacaoBeneficio)){
            $this->fidelityService->deletarBeneficioCamp($CDCAMPANHA, $NRSEQBENEFICIO, $NRSEQPRODCAMP);
        }else{
            $response->addMessage(new Message($this->salesMessage->getMessage(22)));
        }

        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('nothing', array(array('nothing' => 'nothing'))));
    }

    public function altBeneficioCampanha(Request\Filter $request, Response $response){
        $params = $request->getFilterCriteria()->getConditions();

        $CDCAMPANHA         =  $params[0]['value'];
        $NRSEQBENEFICIO     =  $params[1]['value'];
        $CDPRODUTO          =  $params[2]['value'];
        $NRDIASVALBENECAMP  =  $params[3]['value'];
        $QTBENEFICIOCAMP    =  $params[4]['value'];
        $NRORGULTATU        =  $params[5]['value'];
        $CDOPERULTATU       =  $params[6]['value'];

        $NRSEQPRODCAMP = $this->fidelityService->buscaNRSEQPRODCAMP($CDCAMPANHA, $CDPRODUTO);
        $NRSEQPRODCAMP = $NRSEQPRODCAMP[0]['NRSEQPRODCAMP'];

        $this->fidelityService->altBeneficioCampanha($CDCAMPANHA, $NRSEQBENEFICIO, $NRSEQPRODCAMP, $NRDIASVALBENECAMP, $QTBENEFICIOCAMP, $NRORGULTATU, $CDOPERULTATU);

        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('nothing', array(array('nothing' => 'nothing'))));
    }

    public function buscaBeneficioConsumidor(Request\Filter $request, Response $response){
        $params = $request->getFilterCriteria()->getConditions();

        $CDCAMPANHA   =  $params[0]['value'];
        $CDCONSUMIDOR =  $params[1]['value'];
        $CDCLIENTE    =  $params[2]['value'];

        $beneficiosUtilizados    = $this->fidelityService->buscaBeneficioUtilizado($CDCAMPANHA, $CDCONSUMIDOR, $CDCLIENTE);
        $beneficiosNaoUtilizados = $this->fidelityService->buscaBeneficioNaoUtilizado($CDCAMPANHA, $CDCONSUMIDOR, $CDCLIENTE);

        for($i = 0; $i < count($beneficiosUtilizados); ++$i) {

           if($beneficiosUtilizados[$i]['IDTPBENEFICIO'] == 'P'){
                $beneficiosUtilizados[$i]['IDTPBENEFICIO'] = 'DESCONTO PERCENTUAL';
           }else{
                $beneficiosUtilizados[$i]['IDTPBENEFICIO'] = 'DESCONTO VALOR';
           }
        }

        for($i = 0; $i < count($beneficiosNaoUtilizados); ++$i) {

           if($beneficiosNaoUtilizados[$i]['IDTPBENEFICIO'] == 'P'){
                $beneficiosNaoUtilizados[$i]['LABEL'] = $beneficiosNaoUtilizados[$i]['NRSEQBENEFICIO'] . ' DESCONTO PERCENTUAL ' . $beneficiosNaoUtilizados[$i]['VRBENEFICIO'] . '%';
           }else{
                $beneficiosNaoUtilizados[$i]['LABEL'] = $beneficiosNaoUtilizados[$i]['NRSEQBENEFICIO'] . ' DESCONTO VALOR' . ' R$' . $beneficiosNaoUtilizados[$i]['VRBENEFICIO'];
           }
        }

        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('BeneficiosUtilizadosRepo', $beneficiosUtilizados));
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('BeneficiosNaoUtilizadosRepo', $beneficiosNaoUtilizados));
    }

    public function gravarManutBeneficio(Request\Filter $request, Response $response){
        $params = $request->getFilterCriteria()->getConditions();

        $CDCAMPANHA     = $params[0]['value'];
        $CDCLIENTE      = $params[1]['value'];
        $CDCONSUMIDOR   = $params[2]['value'];
        $IDTPBENEFICIO  = $params[3]['value'];
        $NRSEQBENEFICIO = $params[4]['value'];
        $QTDEBENEFICIO  = $params[5]['value'];
        $VRBENEFICIO    = $params[6]['value'];
        $NRSEQPRODCAMP  = $params[7]['value'];
        $NRORG          = $params[8]['value'];
        $NRORGINCLUSAO  = $params[9]['value'];
        $CDOPERINCLUSAO = $params[10]['value'];
        $NRORGULTATU    = $params[11]['value'];
        $CDOPERULTATU   = $params[12]['value'];

        $NRSEQBENECONS = $this->util->newCode('MOVBENEFICIOCONS', '10');

        $checkBeneficioMOVBENEFICIOCTR = $this->fidelityService->checkUtilControlBeneficio($CDCLIENTE, $CDCONSUMIDOR, $CDCAMPANHA, $NRSEQPRODCAMP, $NRSEQBENEFICIO);

        if(empty($checkBeneficioMOVBENEFICIOCTR)){

            $diasValidadebeneficio = $this->fidelityService->buscaDiasValidadben($CDCAMPANHA, $NRSEQPRODCAMP, $NRSEQBENEFICIO);

            $NRDIASVALBENECAMP = $diasValidadebeneficio[0]['NRDIASVALBENECAMP'];

            $DTFIMVALBENECONS   = $this->util->nextNDay($NRDIASVALBENECAMP);
            $DTFIMVALBENECONS   = str_replace("-","/",$DTFIMVALBENECONS);

            $this->fidelityService->insereManutencaoBeneficio($CDCAMPANHA, $CDCLIENTE, $CDCONSUMIDOR, $DTFIMVALBENECONS, $IDTPBENEFICIO, $NRSEQBENEFICIO, $QTDEBENEFICIO, $VRBENEFICIO, $NRSEQPRODCAMP, $NRORG, $NRORGINCLUSAO, $CDOPERINCLUSAO, $NRORGULTATU, $CDOPERULTATU, $NRSEQPRODCAMP);
        }else{
            $QTDEBENEFICIOdatabase = $checkBeneficioMOVBENEFICIOCTR[0]['QTDEBENEFICIO'];
            $QTDEBENEFICIO = $QTDEBENEFICIO + $QTDEBENEFICIOdatabase;

            $this->fidelityService->updateManutencaoBeneficio($QTDEBENEFICIO, $NRORGULTATU, $CDOPERULTATU, $CDCAMPANHA, $CDCLIENTE, $CDCONSUMIDOR, $NRSEQPRODCAMP, $NRSEQBENEFICIO);
        }

        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('nothing', array(array('nothing' => 'nothing'))));
    }

    public function atualizaDataUtilBeneficio(Request\Filter $request, Response $response){
        $params = $request->getFilterCriteria()->getConditions();

        $CDCLIENTE      = $params[0]['value'];
        $CDCONSUMIDOR   = $params[1]['value'];
        $CDCAMPANHA     = $params[2]['value'];
        $NRSEQPRODCAMP  = $params[3]['value'];
        $QTDEBENEFICIO  = $params[4]['value'];
        $DTUTBENECONS   = $params[5]['value'];
        $NRSEQBENEFICIO = $params[6]['value'];
        $NRORG          = $params[7]['value'];
        $NRORGINCLUSAO  = $params[8]['value'];
        $CDOPERINCLUSAO = $params[9]['value'];
        $NRORGULTATU    = $params[10]['value'];
        $CDOPERULTATU   = $params[11]['value'];

        $dadosBeneficio = $this->fidelityService->checkUtilControlBeneficio($CDCLIENTE, $CDCONSUMIDOR, $CDCAMPANHA, $NRSEQPRODCAMP, $NRSEQBENEFICIO);
        $QTDEBENEFICIOdatabase = $dadosBeneficio[0]['QTDEBENEFICIO'];

        if(($QTDEBENEFICIOdatabase - $QTDEBENEFICIO) >= 0 ){
            $QTDEBENEFICIOCTR = $QTDEBENEFICIOdatabase - $QTDEBENEFICIO;

            $this->fidelityService->updateManutencaoBeneficio($QTDEBENEFICIOCTR, $NRORGULTATU, $CDOPERULTATU, $CDCAMPANHA, $CDCLIENTE, $CDCONSUMIDOR, $NRSEQPRODCAMP, $NRSEQBENEFICIO);

            for($i = 0; $i < $QTDEBENEFICIO; ++$i) {
                $NRSEQBENECONS = $this->util->newCode('MOVBENEFICIOCONS', '10');
                $this->fidelityService->insereDataUtilBeneficio($NRSEQBENECONS, $CDCLIENTE, $CDCONSUMIDOR, $CDCAMPANHA, $NRSEQPRODCAMP, $DTUTBENECONS, $NRSEQBENEFICIO, $NRORG, $NRORGINCLUSAO, $CDOPERINCLUSAO, $NRORGULTATU, $CDOPERULTATU);
            }
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('nothing', array(array('nothing' => 'nothing'))));
        }else{
            $response->addMessage(new Message($this->salesMessage->getMessage(36)));
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('nothing', array(array('nothing' => 'nothing'))));
        }


    }

    public function bloquearCartao(Request\Filter $request, Response $response){
        $params = $request->getFilterCriteria()->getConditions();

        $CDIDCONSUMID = $params[0]['value'];

        $verificaCartao = $this->fidelityService->verificarCartao($CDIDCONSUMID);

        if(empty($verificaCartao)){
            $response->addMessage(new Message($this->salesMessage->getMessage(25)));
        }else{
            $this->fidelityService->bloquearCartao($CDIDCONSUMID);
            $response->addMessage(new Message($this->salesMessage->getMessage(24)));
        }
    }

    public function incluirRangeProduto(Request\Filter $request, Response $response){
        $params = $request->getFilterCriteria()->getConditions();

        $CDCAMPANHA        = $params[0]['value'];
        $CDPRODUTO         = $params[1]['value'];
        $CDPRODUTO2        = $params[2]['value'];
        $IDPRODUTOGERA     = $params[3]['value'];
        $VRPONTOPROD       = $params[4]['value'];
        $DTINIVIGPROD      = $params[5]['value'];
        $DTFIMVIGPROD      = $params[6]['value'];
        $NRORG             = $params[7]['value'];
        $NRORGINCLUSAO     = $params[8]['value'];
        $CDOPERINCLUSAO    = $params[9]['value'];
        $NRORGULTATU       = $params[10]['value'];
        $CDOPERULTATU      = $params[11]['value'];

        $CDARVPROD  = $this->produtoService->buscaCDARVPROD($CDPRODUTO);
        $CDARVPROD  = $CDARVPROD[0]['CDARVPROD'];
        $CDARVPROD2 = $this->produtoService->buscaCDARVPROD($CDPRODUTO2);
        $CDARVPROD2 = $CDARVPROD2[0]['CDARVPROD'];

        $produtosRange = $this->produtoService->buscaProdutosRange($CDARVPROD, $CDARVPROD2);

        for($i = 0; $i < count($produtosRange); ++$i) {

            $NRSEQPRODCAMP = $this->util->newCode('PRODCAMPANHA'.$CDCAMPANHA, '10');

            $CDPRODUTOinclusao = $produtosRange[$i]['CDPRODUTO'];
            $checkProdCampanha = $this->fidelityService->buscaProdCampanha($CDCAMPANHA, $CDPRODUTOinclusao);

            if(empty($checkProdCampanha)){
                $this->fidelityService->incluirProduto($CDCAMPANHA, $NRSEQPRODCAMP, $CDPRODUTOinclusao, $IDPRODUTOGERA, $VRPONTOPROD, $DTINIVIGPROD, $DTFIMVIGPROD, $NRORG, $NRORGINCLUSAO, $CDOPERINCLUSAO, $NRORGULTATU, $CDOPERULTATU);
            }
        }

        $produtosCampanha = $this->fidelityService->buscaProdutosCampanha($CDCAMPANHA);

        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('ProdCampanhaRepo', $produtosCampanha));
    }

    public function cadRangeProdBeneCamp(Request\Filter $request, Response $response){
        $params = $request->getFilterCriteria()->getConditions();

        $CDCAMPANHA     = $params[0]['value'];
        $NRSEQPRODCAMP  = $params[1]['value'];
        $NRSEQBENEFICIO = $params[2]['value'];
        $CDPRODUTO      = $params[3]['value'];
        $CDPRODUTO2     = $params[4]['value'];
        $NRORG          = $params[5]['value'];
        $NRORGINCLUSAO  = $params[6]['value'];
        $CDOPERINCLUSAO = $params[7]['value'];
        $NRORGULTATU    = $params[8]['value'];
        $CDOPERULTATU   = $params[9]['value'];

        $CDARVPROD  = $this->produtoService->buscaCDARVPROD($CDPRODUTO);
        $CDARVPROD  = $CDARVPROD[0]['CDARVPROD'];
        $CDARVPROD2 = $this->produtoService->buscaCDARVPROD($CDPRODUTO2);
        $CDARVPROD2 = $CDARVPROD2[0]['CDARVPROD'];

        $produtosRange = $this->produtoService->buscaProdutosRange($CDARVPROD, $CDARVPROD2);

        for($i = 0; $i < count($produtosRange); ++$i) {

            $CDPRODUTOinclusao = $produtosRange[$i]['CDPRODUTO'];

            $verificaProdInclusao = $this->fidelityService->verificaProdBeneCamp($CDCAMPANHA, $NRSEQPRODCAMP, $NRSEQBENEFICIO, $CDPRODUTOinclusao);

            if(empty($verificaProdInclusao)){
                $this->fidelityService->cadProdBeneCamp($CDCAMPANHA, $NRSEQPRODCAMP, $NRSEQBENEFICIO, $CDPRODUTOinclusao, $NRORG, $NRORGINCLUSAO, $CDOPERINCLUSAO, $NRORGULTATU, $CDOPERULTATU);
            }
        }

        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('nothing', array(array('nothing' => 'nothing'))));
    }

    public function buscaProdCampanhaBeneficio(Request\Filter $request, Response $response){
        $params = $request->getFilterCriteria()->getConditions();
        $CDCAMPANHA     = $params[1]['value'];

        $prodsCampBeneficio = $this->fidelityService->buscaProdCampanhaBeneficio($CDCAMPANHA);

        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('BuscaProdCampBenRepo', $prodsCampBeneficio));
    }

    public function geraVoucher($CDCAMPANHA, $CDCLIENTE, $CDCONSUMIDOR){
        $nrseq = null;
        $connection = $this->entityManager->getConnection();
        $storedProcedure = new StoredProcedure($connection, 'GERAVOUCHER');
        $storedProcedure->addParam(new Param('P_CDCAMPANHA', Param::PARAM_INPUT, $CDCAMPANHA, Param::PARAM_TYPE_STR, 10));
        $storedProcedure->addParam(new Param('P_CDCLIENTE', Param::PARAM_INPUT, $CDCLIENTE, Param::PARAM_TYPE_STR, 21));
        $storedProcedure->addParam(new Param('P_CDCONSUMIDOR', Param::PARAM_INPUT, $CDCONSUMIDOR, Param::PARAM_TYPE_STR, 21));
        $result = $storedProcedure->execute();
    }

    public function paramFidelidadeGeral(Request\DataSet $request, Response $response){
        try {
            $rows = $request->getDataSet()->getRows()[0];
            $CDCLIENTEFD  = $rows['CDCLIENTE'];
            $CDTIPOCONSFD = $rows['CDTIPOCONS'];
            $CDCCUSCLIEFD = $rows['CDCCUSCLIE'];
            $this->fidelityService->paramFidelidadeGeral($CDCLIENTEFD, $CDTIPOCONSFD, $CDCCUSCLIEFD);
    
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('nothing', array(array('nothing' => 'nothing'))));
        } catch (\Exception $e){
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    public function buscaParamGeralFidelidade(Request\Filter $request, Response $response) {
        $params = $request->getFilterCriteria()->getConditions();
        try {
            $dadosFidelidadeParamgeral = $this->fidelityService->buscaParamGeralFidelidade($params[0]['value']);
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('BuscaParamGeralRepo', $dadosFidelidadeParamgeral));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }
    //Doação de cartões
    public function criaCartoesDoacao(Request\Filter $request, Response $response){
    	$connection = $this->entityManager->getConnection();
        $connection->beginTransaction();
        try {
	        $params = $request->getFilterCriteria()->getConditions();

	        $CARTAOINI  = $params[0]['value'];
	        $CARTAOFIM  = $params[1]['value'];
	        $CDCAMPANHA = $params[2]['value'];
	        $CDPRODUTO  = $params[3]['value'];
	        $cont = 0; //conta cartoes criados
	        //busca produto selecionado
	        $NRSEQPRODCAMP = $this->fidelityService->buscaNRSEQPRODCAMP($CDCAMPANHA, $CDPRODUTO);
	        $NRSEQPRODCAMP = $NRSEQPRODCAMP[0]['NRSEQPRODCAMP'];
	        //busca beneficios da campanha

	        $beneficiosCampanha = $this->fidelityService->buscaBeneficiosCampanha($CDCAMPANHA, $NRSEQPRODCAMP);

	        $beneficiosCompra = array();

	        for ($i = 0; $i < count($beneficiosCampanha); ++$i) {
	        // caso seja um beneficio ativado na COMPRA DO CARTÃO cria um beneficio
	            if($beneficiosCampanha[$i]['IDTPATIVABENEFICIO'] == '2'){
	            	array_push($beneficiosCompra, $beneficiosCampanha[$i]);
	            }else if($beneficiosCampanha[$i]['IDTPATIVABENEFICIO'] == '1'){
                    $beneficiosCampanha[$i]['QTBENEFICIOCAMP'] = 0;
                    array_push($beneficiosCompra, $beneficiosCampanha[$i]);
                }
	        }
	        for ($CDIDCONSUMID = $CARTAOINI; $CDIDCONSUMID <= $CARTAOFIM; ) {
	        	//dados consumidor
	        	$CDIDCONSUMID =	str_pad($CDIDCONSUMID, 9, "0", STR_PAD_LEFT);
	        	$CDIDCONSUMIDused =  $this->criaDigitoVerificador($CDIDCONSUMID);
	        	$CDCONSUMIDOR = 'DOA'.str_pad($CDIDCONSUMIDused, 18, "0", STR_PAD_LEFT);
	            /* Definir campos não-nulos. */
	            $idatuconsumi = 'S';
	            $idsitconsumi = '1'; //ativo
	            $idconsumidor = 'C';
	            $idtpvendacons = '7';
	            $idimpcpfcupom = 'S';
	            $idcadconflibcon = 'N';
	            $idperconsprodex = 'S';
	            $idtpselmanha = 'N';
	            $idtpsealmoco = 'N';
	            $idtpseltarde = 'N';
	            $idcrachamestre = 'N';
	            $dadosCliente = $this->fidelityService->buscaParamGeralFidelidade();
	            $CDCLIENTE = $dadosCliente[0]['CDCLIENTE'];
	            $CDCCUSCLIE = $dadosCliente[0]["CDCCUSCLIEFD"];

	            /* Prepara os dados para o INSERT. */
	            $params = array(
	                ':CDCLIENTE'       => $CDCLIENTE,
	                ':CDCONSUMIDOR'    => $CDCONSUMIDOR,
	                ':CDIDCONSUMID'    => $CDIDCONSUMIDused,
	                ':NMCONSUMIDOR'    => "Cartão doado",
	                ':IDSITCONSUMI'    => $idsitconsumi,
	                ':CDCCUSCLIE'      => $CDCCUSCLIE,
	                ':IDCONSUMIDOR'    => $idconsumidor,
	                ':IDATUCONSUMI'    => $idatuconsumi,
	                ':IDTPVENDACONS'   => $idtpvendacons,
	                ':IDIMPCPFCUPOM'   => $idimpcpfcupom,
	                ':IDCADCONFLIBCON' => $idcadconflibcon,
	                ':IDPERCONSPRODEX' => $idperconsprodex,
	                ':IDTPSELMANHA'    => $idtpselmanha,
	                ':IDTPSEALMOCO'    => $idtpsealmoco,
	                ':IDTPSELTARDE'    => $idtpseltarde,
	                ':IDCRACHAMESTRE'  => $idcrachamestre,
	            );


	           	// validar se o CDIDCONSUMID já existe
	           	//se ja existe da rollback e manda mensagem de erro
	            $consumer = $this->consumidorService->buscaConsumidor($CDIDCONSUMIDused);
	           	if (!empty($consumer)) {
	           		throw new \Exception($this->salesMessage->getMessage(76).$CDIDCONSUMIDused.'.');
	           	} else {
		            //cria o cartao (consumidor)
		            $this->fidelityService->criaCartaoDoacao($params);
		            //cria o beneficio
		            foreach ($beneficiosCompra as $beneficioCompra) {
			    	    //busca em uma query
				        $IDTPDESBENECONS = $beneficioCompra['IDTPBENEFICIO']; //query beneficio
				        $NRSEQBENEFICIO  = $beneficioCompra['NRSEQBENEFICIO'];//query
				        $VRDESBENECONS   = $beneficioCompra['VRBENEFICIO'];   //query
				        $NRSEQPRODCAMP   = $beneficioCompra['NRSEQPRODCAMP'];  //query
				        //tem a opçaõ de anotar o operador que gerou os beneficios
				        $CDOPERINCLUSAO  = null;
				        $CDOPERULTATU    = null;
						//fixo no codigo!!!!
				        $NRORG          = '1';
				        $NRORGINCLUSAO  = '1';
				        $NRORGULTATU    = '1';
				        $QTDEBENEFICIO  = $beneficioCompra['QTBENEFICIOCAMP'];
				        $IDIMPTMOVCTR   = 'N';
						//DTINIVALBENECONS = "hoje"
			            $NRDIASVALBENECAMP = $beneficioCompra['NRDIASVALBENECAMP'];

			            $DTFIMVALBENECONS   = $this->util->nextNDay($NRDIASVALBENECAMP);
			            $DTFIMVALBENECONS   = str_replace("-","/",$DTFIMVALBENECONS);
			            $this->fidelityService->insereBeneficioDoacao($CDCAMPANHA, $CDCLIENTE, $CDCONSUMIDOR,
			            $DTFIMVALBENECONS, $IDTPDESBENECONS, $NRSEQBENEFICIO, $QTDEBENEFICIO, $VRDESBENECONS,
			            $NRSEQPRODCAMP, $NRORG, $NRORGINCLUSAO, $CDOPERINCLUSAO, $NRORGULTATU, $CDOPERULTATU, $IDIMPTMOVCTR);
		            }
             		//acrescimo nos contadores
		            $cont++;
		            $CDIDCONSUMID++;
	       		}
	       	}
	        $message = $cont.' '.$this->salesMessage->getMessage(73);
	        $message = array('messageOk' => $message);
            $connection->commit();
            $cartoes = $this->fidelityService->getCartoes();
	        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('CriaCartoesDoacaoRepo', $message));
	        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('GetCartoesRepo', $cartoes));
		} catch (\Exception $e) {
            /* Undo changes in case of failure. */
            $connection->rollback();
            /* Send failure message to the main function. */
            $response->addMessage(new Message($e->getMessage()));
            //throw new \Exception($this->salesMessage->getMessage(77));
        }
    }

    public function criaDigitoVerificador($cartao){

    	$digito = 0;
        $soma = 0;
        $temp = $cartao;
        $fator =2;
        //cria numero verificador
        //multiplica cada digito dependendo do resto da divisao dele por 2
        //soma o resultado
        for ($i = strlen($cartao) - 1; $i >= 0; $i--) {
        	$soma = $temp[$i]*$fator;
        //se o resultado tiver mais que 1 digito soma os 2 digitos
	        if($soma>9){
	         	$soma = ((int)$soma/10) + ((int)$soma%10);
	        }
	        $digito = $digito + (int)$soma;
	    //alterna o fator
        	if($fator == 2){
				$fator = 1;
        	} else{
        		$fator = 2;
        	}
        }
        $resto = $digito % 10;
        //se o resto da divisao por 10 for zero retorna zero, senao retorna resto-10
        if ($resto == 0 ){
        	$digito = 0;
        }else{
	    // a diferença de 10
	        $digito = 10 - $resto;
        }
    	//retorna os 10 digitos
    	return $cartao.(int)$digito;
    }

    public function getCartoes(Request\Filter $request, Response $response){
        $cartoes = $this->fidelityService->getCartoes();
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('GetCartoesRepo', $cartoes));
    }
    public function criaCartoesFidelidade(Request\Filter $request, Response $response){
        try {
	        $params = $request->getFilterCriteria()->getConditions();

	        $CARTAOINI  = $params[0]['value'];
	        $CARTAOFIM  = $params[1]['value'];
            $EMAIL      = $params[2]['value'];
            $EMAIL      = strtolower($EMAIL);
	        $cartoes ="<br/>";

    		for ( $cont = $CARTAOINI; $cont <= $CARTAOFIM ; $cont++) {
    			$CDIDCONSUMID =	str_pad($cont, 9, "0", STR_PAD_LEFT);
	        	$CDIDCONSUMID =  $this->criaDigitoVerificador($CDIDCONSUMID);
	        	$cartoes = $cartoes.$CDIDCONSUMID."<br/>";
			}

	        $subject  = $this->salesMessage->getMessage('104');
			$sender = $this->salesMessage->getMessage('102');
			$content =
				'<p>Criação de cartoes fidelidade Odhen Manage.</p>'.
	            '<p>Se não requisitou este teste, ignore essa mensagem.<b><br>'.
	            '<p>Segue a lista de cartoes validos<b><br>'.
                $cartoes
			;

			$this->SMTPService->sendEmail($EMAIL, $EMAIL, $sender, $subject, $content);
            $response->addMessage(new Message($this->salesMessage->getMessage(80)));
		} catch (\Exception $e) {
            /* Send failure message to the main function. */
            $response->addMessage(new Message($this->salesMessage->getMessage(72)));
        }
    }

    public function saveAvailableBenefits(Request\Filter $request, Response $response){
        try {
            $params = $request->getFilterCriteria()->getConditions();

            $CDCLIENTE = $params[0]['value'];
            $CDCONSUMIDOR = $params[1]['value'];
            $CDCAMPANHA = $params[2]['value'];
            $NRSEQBENEFICIO = $params[3]['value'];
            $DTINIVALBENECONS = $params[4]['value'];
            $DTFIMVALBENECONS = $params[5]['value'];
            $NRSEQPRODCAMP = $params[6]['value'];

            $this->fidelityService->updateBenefitExpiration($CDCLIENTE, $CDCONSUMIDOR, $CDCAMPANHA, $NRSEQBENEFICIO, $DTINIVALBENECONS, $DTFIMVALBENECONS);
            $availableBenefits = $this->fidelityService->buscaBeneficiosDisponiveis($CDCAMPANHA, $CDCLIENTE, $CDCONSUMIDOR, $NRSEQPRODCAMP);
            
            for($i = 0; $i < count($availableBenefits); ++$i){
                if ($availableBenefits[$i]['IDTPBENEFICIO'] == 'P')
                    $availableBenefits[$i]['LABEL'] = $availableBenefits[$i]['NRSEQBENEFICIO'] .' DESCONTO PERCENTUAL '. $availableBenefits[$i]['VRBENEFICIO'].'%' ;
                else
                    $availableBenefits[$i]['LABEL'] = $availableBenefits[$i]['NRSEQBENEFICIO'] .' DESCONTO VALOR '. $this->util->formataDinheiro($availableBenefits[$i]['VRBENEFICIO']);
            }
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('BenDisponiveisRepo', $availableBenefits));
        } catch (\Exception $e){
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    public function importDSBENEFICIO(Request\Filter $request, Response $response){
        try {
            $beneficios = $this->fidelityService->buscaBeneficios();
            foreach ($beneficios as $beneficio) {
                if($beneficio['DSBENEFICIO'] == NULL || $beneficio['DSBENEFICIO'] == ''){
                    $DSBENEFICIO = 'alguma coisa';
                    $this->fidelityService->alteraDSBENEFICIO($beneficio['NRSEQBENEFICIO'], $DSBENEFICIO);
                }
            }

        } catch (\Exception $e){
            $response->addMessage(new Message($e->getMessage()));
        }
    }
    
    public function findBeneficioCamp(Request\Filter $request, Response $response){
        $params = $request->getFilterCriteria()->getConditions();
            $array = [];
            $CDCONSUMIDOR = $params[0]['value'];
            $CDCAMPANHA = $params[1]['value'];
            $CDCLIENTE = $params[2]['value'];
            $NRORG = $params[3]['value'];
        try {
            $beneficios = $this->fidelityService->buscaBeneficiosCamp($NRORG, $CDCAMPANHA, $CDCONSUMIDOR, $CDCLIENTE);
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('Beneficios', $beneficios));
        } catch (\Exception $e){
            $response->addMessage(new Message($e->getMessage()));
        }
    }
}