<?php

namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\Controller\CrudWithParameterBag;

class SelectVendedorMultipleFilialCaixa extends CrudWithParameterBag {
    const dataSourceConsumidor  = 'select_vendedor_by_multiple_filial_caixa';
    
    protected $parameterBagColumnsConsumidor = array('CDFILIAL', 'TCDCAIXA', 'CDCAIXA');
    
    public function __construct ($parameterBag, Manager $dataSourceManager, $utilService) {
        $this->parameterBag             = $parameterBag;
        $this->dataSourceManager        = $dataSourceManager;
        $this->utilService              = $utilService;
    }
    
    public function find (DTO\Request\Filter $request, DTO\Response $response){
        $this->dataSourceName      = self::dataSourceConsumidor;
        $this->parameterBagColumns = $this->parameterBagColumnsConsumidor;
        $conditions                = $this->utilService->getParamsAsArray($request);
        $dataSourceFilter          = SelectVendedorMultipleFilialCaixa::prepareParameters($conditions);
        $requestDataSourceFilter = $request->getFilterCriteria()->getConditions();
        
        foreach($requestDataSourceFilter as $filter) {
            if($filter['operator'] === 'MAPPED_LIKE_ALL') {
                array_push($dataSourceFilter, $filter);
            }
        }
        
        $newRequest = new DTO\Request\Filter(
            new FilterCriteria(
                $this->dataSourceName,
                $dataSourceFilter,
                $request->getFilterCriteria()->getPage()
            ),
            $request->getMethod(),
            $request->getRoutePath(),
            $request->getUserId()
        );
        
        parent::find($newRequest, $response);
    }
    
    private function prepareParameters($conditions) {
        if(isset($conditions['CDFILIAL'])){
            if(is_array($conditions['CDFILIAL'])) {
                $CDFILIAL = implode('_', $conditions['CDFILIAL']);
            } else {
                $CDFILIAL = $conditions['CDFILIAL'];
            }
            
            $TCDFILIAL = NULL;
            
        } else {
            $CDFILIAL = NULL;
            $TCDFILIAL = 'T';
        }
        
        if(isset($conditions['CDCAIXA']) && !!$conditions['CDCAIXA']){
            $CDCAIXA = implode('_', $conditions['CDCAIXA']);
            $TCDCAIXA = NULL;
            
        } else {
            $CDCAIXA = NULL;
            $TCDCAIXA = 'T';
        }
        
        $parameters = array(
            'CDFILIAL'  => $CDFILIAL,
            'TCDCAIXA'   => $TCDCAIXA,
            'CDCAIXA'    => $CDCAIXA
        );
        
        $dataSourceFilter = array();
        
        $dataSourceFilter[0] = array(
            "columnName" => 'CDFILIAL',
            "operator"   => "=",
            "value"      => $parameters['CDFILIAL']
        ); 
        $dataSourceFilter[1] = array(
            "columnName" => 'TCDCAIXA',
            "operator"   => "=",
            "value"      => $parameters['TCDCAIXA']
        );
        $dataSourceFilter[2] = array(
            "columnName" => 'CDCAIXA',
            "operator"   => "=",
            "value"      => $parameters['CDCAIXA']
        );
        
        return $dataSourceFilter;
    }
}